{% extends "bee_django_crm/base.html" %}
{% load static %}
{% block styles %}
    <style>

        body {
            margin: 0;
            padding: 0;
            background-color: #f5f5f5;

        }

    </style>
{% endblock %}
{% block content %}
    <div class="text-center" style="margin-top:100px;">
        <img src="{% static 'bee_django_crm/img/preuser_done.jpg' %}" alt="注册成功">
    </div>
    <div class="text-center">
        <h3><span style="font-weight: 900;">报名已成功</span></h3>
    </div>
{% endblock %}