{% extends "bee_django_crm/base.html" %}
{% load bee_django_crm_filter %}
{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    <h4>个人详情</h4>
    {% if perms.bee_django_crm.change_preuser %}
    <a href="{% url 'bee_django_crm:preuser_update'  preuser.id %}">修改信息</a>
    {% endif %}
    <table class="table">
        <tr>
            <td class="col-xs-4">姓名</td>
            <td>{{ preuser.name|default:"" }}</td>
        </tr>
        <tr>
            <td>电话</td>
            <td>{{ preuser.mobile|default:"" }}</td>
        </tr>
        <tr>
            <td>性别</td>
            <td>{{ preuser.get_gender|default:"" }}</td>
        </tr>
        <tr>
            <td>微信</td>
            <td>{{ preuser.wx|default:"" }}</td>
        </tr>

        <tr>
            <td>生日</td>
            <td>{{ preuser.birthday|date:"Y-m-d"|default:"" }}</td>
        </tr>
        <tr>
            <td>来源</td>
            <td>{{ preuser.get_source|default:"" }}</td>
        </tr>
        <tr>
            <td>推荐人</td>
            <td>{{ preuser|get_referral_user_name:1|default:"" }}</td>
        </tr>
        <tr>
            <td>接引人</td>
            <td>{{ preuser|get_referral_user_name:2|default:"" }}</td>
        </tr>
        <tr>
            <td>城市</td>
            <td>{{ preuser.province|default:"" }}{{ preuser.city|default:"" }}</td>
        </tr>
        <tr>
            <td>地址</td>
            <td>{{ preuser.address|default:"" }}</td>
        </tr>
        <tr>
            <td>工作</td>
            <td>{{ preuser.job|default:"" }}</td>
        </tr>
        <tr>
            <td>email</td>
            <td>{{ preuser.email|default:"" }}</td>
        </tr>
        <tr>
            <td>爱好</td>
            <td>{{ preuser.hobby|default:"" }}</td>
        </tr>
        <tr>
            <td>婚姻状况</td>
            <td>{{ preuser.married|default:"" }}</td>
        </tr>
        <tr>
            <td>孩子状况</td>
            <td>{{ preuser.children|default:"" }}</td>
        </tr>
        <tr>
            <td>工作详情</td>
            <td>{{ preuser.job_info|default:"" }}</td>
        </tr>
        <tr>
            <td>孩子状况</td>
            <td>{{ preuser.children|default:"" }}</td>
        </tr>
        <tr>
            <td>家庭详情</td>
            <td>{{ preuser.family|default:"" }}</td>
        </tr>
    </table>
    <hr>
    <h4>申请表</h4>
    <a href="{% url 'bee_django_crm:preuser_application_add' preuser.id %}">专属申请表链接</a>
    <table class="table">
        {% for data in application %}
            <tr>
                <td class="col-xs-4">{{ data.question.name }}</td>
                <td>{{ data.answer }}</td>
            </tr>
        {% endfor %}
    </table>
    <hr>
    <h4>联络记录</h4>
    <a href="{% url 'bee_django_crm:preuser_track_add' preuser.id %}">增加联络记录</a>
    <table class="table">
        {% for track in track_list %}

            <tr>
                <td class="col-xs-4">{{ track.info }}</td>
                <td>{{ track.tracked_at|local_datetime|date:"Y-m-d H:i:s" }}</td>
            </tr>
        {% endfor %}
    </table>
    <hr>
    <h4>合同管理</h4>
    <a href="{% url 'bee_django_crm:preuser_contract_add' preuser.id %}">添加合同</a>
    <table class="table">
        {% for user_contract in contract_list %}

            <tr>
                <td class="col-xs-4">{{ user_contract.contract.name }}</td>
                <td><a
                        href="{% url 'bee_django_crm:preuser_contract_detail' user_contract.id %}">详情</a></td>
            </tr>
        {% endfor %}
    </table>
    <hr>
    <h4>缴费明细</h4>
    <table class="table">
        {% for user_fee in fee_list %}

            <tr>
                <td class="col-xs-4">{{ user_fee.preuser_contract.contract.name }}</td>
                <td>{{ user_fee.get_pay_status}}</td>
                <td>{{ user_fee.paid_at|date:"Y-m-d"}}</td>
                <td>{{ user_fee.price}}</td>
                <td><a
                        href="{% url 'bee_django_crm:preuser_fee_detail' user_fee.id %}">详情</a></td>
            </tr>
        {% endfor %}
    </table>
    <hr>
{% endblock %}