{% extends "bee_django_crm/base.html" %}
{% load static %}

{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    {{ poster_name }}的图片
    <form method="post" enctype="multipart/form-data">
        {% csrf_token %}

        {{ form.as_ul }}
        <div style="color: red;margin: 10px 0;">图片建议： 尺寸为500*666，大小100K左右</div>
        <input type="submit" value="下一步"/>
    </form>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {

        });
    </script>
{% endblock %}