# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-23 08:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0007_auto_20180823_1533'),
    ]

    operations = [
        migrations.AddField(
            model_name='preuser',
            name='pay_status',
            field=models.IntegerField(choices=[(0, b'\xe6\x9c\xaa\xe7\xbc\xb4\xe8\xb4\xb9'), (1, b'\xe5\x85\xa8\xe6\xac\xbe\xe7\xbc\xb4\xe6\xb8\x85'), (2, b'\xe5\x88\x86\xe6\x9c\x9f\xe4\xb8\xad')], default=0, verbose_name=b'\xe7\xbc\xb4\xe8\xb4\xb9\xe6\x83\x85\xe5\x86\xb5'),
        ),
    ]
